@@ -117,13 +117,13 @@ class Equals(Formula):
 
     def to_sql(self) -> str:
         if isinstance(self.left, tuple):  # (variable, attr_name)
-            left_string = f'"{self.left[0].name}.{self.left[1]}"'
+            left_string = f'{self.left[0].name}."{self.left[1]}"'
         elif isinstance(self.left, str):
             left_string = f'\'{self.left}\''
         else:
             left_string = f'{self.left}'
         if isinstance(self.right, tuple):  # (variable, attr_name)
-            right_string = f'"{self.right[0].name}.{self.right[1]}"'
+            right_string = f'{self.right[0].name}."{self.right[1]}"'
         elif isinstance(self.right, str):
             right_string = f'\'{self.right}\''
         else:
